# https://github.com/fsfe/reuse-tool

Name:           reuse
Version:        5.0.2
Release:        %mkrel 1
Summary:        A tool for compliance with the REUSE recommendations
Group:          File tools
License:        GPLv3+ and CC-BY-SA and ASL 2.0
Url:            https://reuse.software/
Source0:        %pypi_source
Source1:        https://raw.githubusercontent.com/fsfe/reuse-tool/main/CONTRIBUTING.md
Patch0:         reuse-fix-reqs.patch
Patch1:         0001-Use-importlib-mode-for-pytest.patch
BuildArch:      noarch

# Build
BuildRequires:  pyproject-rpm-macros
BuildRequires:  gettext
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
# Test
BuildRequires:  git
BuildRequires:  mercurial
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(freezegun)
# Dependencies
BuildRequires:  python3dist(jinja2)
BuildRequires:  python3dist(binaryornot)
BuildRequires:  python3dist(boolean-py)
BuildRequires:  python3dist(license-expression)
BuildRequires:  python3dist(poetry)
BuildRequires:  python3dist(python-debian)
BuildRequires:  python3dist(requests)
# Documentation
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(sphinx-autodoc-typehints)
BuildRequires:  python3dist(sphinxcontrib-apidoc)
BuildRequires:  python3dist(furo)
BuildRequires:  python3dist(myst-parser)

Recommends:     git
Recommends:     mercurial

Provides:       reusetool = %{version}-%{release}

%description
A tool for compliance with the REUSE recommendations. Essentially,
it is a linter that checks for a project's compliance, and a compiler that
generates a project's bill of materials.

%prep
%autosetup -p1

cp -a %{S:1} .

%generate_buildrequires
%pyproject_buildrequires -t

%build
%pyproject_wheel

pushd docs
PBR_VERSION=%{version} sphinx-build-%{python3_version} . html
PBR_VERSION=%{version} sphinx-build-%{python3_version} -b man . manpages
rm -rf {html,man}/.{doctrees,buildinfo}
popd

%install
%pyproject_install

%pyproject_save_files reuse

install -p -m0644 -Dt "%{buildroot}%{_mandir}/man1" docs/manpages/*.1

%check
#pytest

%files -f %{pyproject_files}
%license LICENSES/*.txt
%doc README.md CHANGELOG.md docs/html/
%{_bindir}/%{name}
%{_mandir}/man1/reuse.1*
%{_mandir}/man1/reuse-*.1*


%changelog
* Thu Nov 14 2024 daviddavid <daviddavid> 5.0.2-1.mga10
+ Revision: 2115513
- new version: 5.0.2

* Thu Jul 11 2024 daviddavid <daviddavid> 4.0.3-1.mga10
+ Revision: 2080683
- new version: 4.0.3

* Mon Jul 08 2024 daviddavid <daviddavid> 4.0.2-1.mga10
+ Revision: 2080319
- new version: 4.0.2

* Sun Apr 21 2024 daviddavid <daviddavid> 3.0.2-1.mga10
+ Revision: 2060213
- new version: 3.0.2
- add virtual provides on reusetool

* Sun Jan 21 2024 daviddavid <daviddavid> 3.0.1-1.mga10
+ Revision: 2033193
- new version: 3.0.1
- remove merged upstream patch

* Thu Dec 28 2023 daviddavid <daviddavid> 2.1.0-2.mga10
+ Revision: 2023262
- rebuild for py3.12

* Fri Dec 01 2023 daviddavid <daviddavid> 2.1.0-1.mga10
+ Revision: 2011979
- new version: 2.1.0

* Sat Feb 11 2023 daviddavid <daviddavid> 1.1.2-1.mga9
+ Revision: 1940107
- new version: 1.1.2

* Wed Feb 08 2023 papoteur <papoteur> 1.1.1-2.mga9
+ Revision: 1939501
- fix python-debian dependency

* Mon Feb 06 2023 daviddavid <daviddavid> 1.1.1-1.mga9
+ Revision: 1938908
- new version: 1.1.1
- switch to pyproject

* Wed Dec 07 2022 daviddavid <daviddavid> 1.0.0-1.mga9
+ Revision: 1918851
- initial package reuse

